@@ -4,7 +4,7 @@ import json
 import logging
 from typing import Any, Dict
 
-from mythx_cli.payload.util import patch_truffle_bytecode, zero_srcmap_indices
+from mythx_cli.payload.util import patch_truffle_bytecode, set_srcmap_indices
 
 LOGGER = logging.getLogger("mythx-cli")
 
@@ -42,10 +42,10 @@ def generate_truffle_payload(file: str) -> Dict[str, Any]:
         "deployed_bytecode": patch_truffle_bytecode(artifact.get("deployedBytecode"))
         if artifact.get("deployedBytecode") != "0x"
         else None,
-        "source_map": zero_srcmap_indices(artifact.get("sourceMap"))
+        "source_map": set_srcmap_indices(artifact.get("sourceMap"))
         if artifact.get("sourceMap")
         else None,
-        "deployed_source_map": zero_srcmap_indices(artifact.get("deployedSourceMap"))
+        "deployed_source_map": set_srcmap_indices(artifact.get("deployedSourceMap"))
         if artifact.get("deployedSourceMap")
         else None,
         "sources": {
